#
# spec file
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define modname python-stdnum
%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-%{modname}
Version:        1.17
Release:        1.9
Summary:        Python module to handle standardized numbers and codes
License:        LGPL-2.0-or-later
URL:            https://arthurdejong.org/python-stdnum/
Source:         https://files.pythonhosted.org/packages/source/p/python-stdnum/%{modname}-%{version}.tar.gz
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Suggests:       python-PySimpleSOAP
Suggests:       python-suds
BuildArch:      noarch
%python_subpackages

%description
This library offers functions for parsing, validating and reformatting
standard numbers and codes in various formats.

Apart from the validate() function, modules generally provide extra
parsing, validation, formatting or conversion functions.

%prep
%setup -q -n %{modname}-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export LANG=en_US.UTF-8
%pytest

%files %{python_files}
%license COPYING
%doc NEWS ChangeLog README.md
%{python_sitelib}/*

%changelog
* Tue Oct 26 2021 Matej Cepl <mcepl@suse.com>
- Fix incorrect update: it is README.md not README these days.
* Sat Oct 23 2021 Axel Braun <axel.braun@gmx.de>
- version 1.17
  for changeslog see NEWS
* Fri Mar 20 2020 Tomáš Chvátal <tchvatal@suse.com>
- Drop not really needed nose dependency
* Fri Mar 20 2020 pgajdos@suse.com
- version update to 1.13
  * Add modules for the following number formats:
  - ESR, ISR, QR-reference (reference number on Swiss payment slips)
    (thanks Kurt Keller)
  - ID number (South African Identity Document number)
  * Add format function for ISO 11649 numbers (thanks Kurt Keller)
  * Add support for Python 3.8 (thanks Sergi Almacellas Abellana)
  * Clarify that the Italian Codice Fiscale can also be the IVA for companies
    (thanks Nicholas Fiorentini)
  * Support the new Dutch btw-identificatienummer (thanks Cas Vissers,
    Jeroen van Heiningen, Jerome Hanke, Nicolas Martinelli, Ronald Portier and
    Tim Muller)
  * Extend test for Argentinian CUIT to check first two digits
  * Add more country codes to ISIN (thanks nocluebutalotofit, Anwar Baroudi and
    alexbond73)
  * Add modules for the following number formats:
  - NRT (Número de Registre Tributari, Andorra tax number)
    (thanks Leandro Regueiro)
  - CPF (Cédula de Persona Física, Costa Rica physical person ID number)
    (thanks Leandro Regueiro)
  - CPJ (Cédula de Persona Jurídica, Costa Rica tax number)
    (thanks Leandro Regueiro)
  - CR (Cédula de Residencia, Costa Rica foreigners ID number)
    (thanks Leandro Regueiro)
  - NIT (Número de Identificación Tributaria, Guatemala tax number)
    (thanks Leandro Regueiro)
  - Identity Number (Mispar Zehut, מספר זהות, Israeli identity number)
  - CN (法人番号, hōjin bangō, Japanese Corporate Number)
    (thanks Alan Hettinger)
  - RRN (South Korean resident registration number)
    (thanks Dimitri Papadopoulos)
  - IRD number (New Zealand Inland Revenue Department (Te Tari Tāke) number)
    (thanks Leandro Regueiro)
  - CUI (Cédula Única de Identidad, Peruvian identity number)
  - RUC (Registro Único de Contribuyentes, Peruvian company tax number)
  - RUC number (Registro Único de Contribuyentes, Paraguay tax number)
    (thanks Leandro Regueiro)
  - VKN (Vergi Kimlik Numarası, Turkish tax identification number)
    (thanks Leandro Regueiro)
  - RUT (Registro Único Tributario, Uruguay tax number)
    (Leandro Regueiro)
  - RIF (Registro de Identificación Fiscal, Venezuelan VAT number)
    (thanks Kevin Kaiser)
  - TIN (South African Tax Identification Number) (thanks Leandro Regueiro)
  * Support GTIN (EAN-14) validation as part of EAN
    (thanks Sergi Almacellas Abellana)
  * Support Dominican Republic e-CF within NCF (thanks Jeffry Jesus De La Rosa)
  * Fix Dominican Republic DGII lookups of NCF (thanks Jeffry Jesus De La Rosa)
  * Fix German Handelsregisternummer to not confuse Hamburg with Homburg and to
    accept shorter numbers (thanks Kevin Kaiser)
  * Support lookups of German Handelsregisternummer in OffeneRegister.de web
    service
  * Handle - and + sign correctly in Swedish Personnummer
    (thanks Amin Solhizadeh)
  * Provide various personalid and vat aliases for existing numbers
    (thanks Andreas Häber)
  * Improve descriptions of Spanish codes (thanks Gerard Dalmau)
  * Fix handling and normalisation of various Unicode digit representations
    (thanks Helge Munk Jacobsen)
* Fri Apr 12 2019 pgajdos@suse.com
- version update to 1.11
  * Add modules for the following number formats:
  - DNI (Documento Nacional de Identidad, Argentinian national identity nr.)
  - VNR, SVNR, VSNR (Versicherungsnummer, Austrian social security number)
  - NI (Número de identidad, Cuban identity card numbers)
  - AMKA (Αριθμός Μητρώου Κοινωνικής Ασφάλισης, Greek social security number)
  - Asmens kodas (Lithuanian, personal numbers)
  - MAC address (Media Access Control address)
  - IDNO (Moldavian company identification number)
  - CURP (Clave Única de Registro de Población, Mexican personal ID)
  - Fødselsnummer (Norwegian birth number, the national identity number) (thanks Ilya Vihtinsky)
  - New Zealand bank account number
  - Personnummer (Swedish personal identity number) (thanks Ilya Vihtinsky)
  * Code style improvements
  * Change Dominican Republic DGII check URL to HTTPS (thanks Gustavo Valverde)
  * Support Ecuadorian Cedula and RUC of foreigners (thanks Christopher Ormaza)
  * Add format() function for Argentinian CUIT number (thanks Mario Puntin)
  * Support passing formatted numbers to all get_birth_date() and similar functions
  * Handle Dominican Republic DGII lookup returning multiple entities (thanks Andrés R)
* Fri Dec  7 2018 Tomáš Chvátal <tchvatal@suse.com>
- Version update to 1.10:
  * More formats supported
  * More expanded testsuite
  * Many bugfixes
* Fri Dec  7 2018 Tomáš Chvátal <tchvatal@suse.com>
- Fix fdupes call
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Thu Jun 29 2017 jmatejek@suse.com
- convert to singlespec
- enable tests
- update to 1.6
  * support more number formats
  * many bugs fixed
  * extended test suite
* Fri Sep 23 2016 jengelh@inai.de
- Trim redundant lines off description
* Mon Jul  4 2016 axel.braun@gmx.de
- update to version 1.3
* Wed Jun 29 2016 axel.braun@gmx.de
- change package name to namingconventions
* Mon Jan  4 2016 axel.braun@gmx.de
- Version 1.2
  initial OBS build
